Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Baguette_sharp.Array_manipulationSourceThe Array Manipulation Module of the B# STD
A generic function to extract two parameters from the list and apply a function
Creates a list containing n times the element default
Takes an array and an integer and returns tbl.(n)
val proto_replace :
Parser.parameters ->
Parser.parameters ->
Parser.parameters ->
Parser.parametersTakes an array, an integer and an element and performs tbl.(n) <- rp
val proto_populate :
Parser.parameters ->
Parser.parameters ->
Parser.parameters ->
Parser.parametersPopulate the tbl with times default
Create an array of size n populated by default
val proto_create_matrix :
Parser.parameters ->
Parser.parameters ->
Parser.parameters ->
Parser.parametersCreate a matrix of size n p populated by default
Creates the access function
Creates the create function
Creates the replace function
Creates the populate function
Create the create_matrix function
Transform an array into a string