Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Baguette_sharp.String_manipulationSourceThe String Manipulation Module of the B# STD
A Generic function to extract two arguments and apply a function
val three_argument_func :
('a -> 'a -> 'a -> Parser.parameters) ->
'a list ->
Parser.parametersA Generic function to extract three arguments and apply a function
Takes an integer and a string and returns a string of n times the inputed one
val proto_replace :
Parser.parameters ->
Parser.parameters ->
Parser.parameters ->
Parser.parametersTake three strings and returns a string where all occurence of s2 have been replaced by s3 in s1
Transform a string into a list of character (but in the type String)
Takes a string and transform it into an array of char with explode
Extract the string from a parameter
Transform an array into a string
Takes two string and returns s1^s2
Takes an integer and a string and returns s.n
Split s1 at every s2 occurences
Creates the function with the generic method and the proto one
Conversion
Converts an element to a string
Converts a string to an integer
Converts a string to a float
Converts a string to a boolean