Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Baguette_sharp.LexerSourceGeneral lexer module : generate lexers char by char or word by word (default)
Take a word and if the lexer is between quotes and returns the corresponding token with Token#string_to_token
Returns the maximum of a list
Take a string and returns the biggest token matching the keyword
Runs the type inference algorithm
Take a string with a token in it and returns a couple of Tokens
The char by char lexer
The word by word lexers
A function to count the parenthesis and validate if every parenthesis are closed and every quotes are doubled
Algorithm if a parenthesis is closed without having been opened then the token is eliminated at the end close parenthesis are added in case of too much opened parenthesis