Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Baguette_sharp.MathSourceThe Math Module of the B# STD
Transforms a parameter into a float
Transforms a list of parameters into a list of floats
Transforms a couple of arguments into a couple of floats
A O(n) in time and O(1) in space iterative fibbonacci function
Computes the sum of the list
Computes the multiplication of the list
Gives the nth element of the fibbonacci sequence
Exponentiate a^b
Computes the square root of the input
Computes the substraction (a-b) of the first two numbers of the input list
Computes the division (a/b) with the first two elements of the list
Returns a random integer in a,b
Computes the logarithm of a in base b
Returns the opposite of the input
Returns the floor of the input
Returns the ceil of the input