Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Baguette_sharp.ParserSourceParser module
Exceptions
Type argument: every primitive type the language recognize
type parameters = | CallExpression of string| Argument of arguments| GOTO of string| LOAD of string| Exception of bag_exception| Label of string| IF| COND| Array| TBL of parameters array| Function of string * string listType parameters: every structure the language recognize
Printing utility
Transform an argument into a string for the REPL
Transforms a parameter into a string
Transform a list of parameters into a string representation
Pretty-print (transforms into a string) an AST
Parsing methods
Parse a string recursively until it encounters a closing quote
Parse a line (a list of tokens) into a a list of ASTs
Parse a file using parse line
Parameters/Arguments utility functions
Creates an integer argument and wraps it into a parameter
Creates a float argument and wraps it into a parameter
Creates a boolean argument and wraps it into a parameter
Creates a string argument and wraps it into a parameter
Parameters algebra function
Adds two parameters
Checks for equality between two parameters
Checks for the <= between two parameters
Checks for the < between two parameters
Checks for the >= between two parameters
Checks for the > between two parameters
Multiply two numbers
Exponentiate a^b
Divide a/b
Subtract two number
Apply a binary operator for two booleans
Apply an unary operator on a boolean